summaryrefslogtreecommitdiffstats
path: root/kdesu/kdesud/secure.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdesu/kdesud/secure.cpp')
-rw-r--r--kdesu/kdesud/secure.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdesu/kdesud/secure.cpp b/kdesu/kdesud/secure.cpp
index 3abda20bc..9b30ab4ee 100644
--- a/kdesu/kdesud/secure.cpp
+++ b/kdesu/kdesud/secure.cpp
@@ -1,6 +1,6 @@
/* vi: ts=8 sts=4 sw=4
*
* This file is part of the KDE project, module kdesu.
* Copyright (C) 1999,2000 Geert Jansen <g.t.jansen@stud.tue.nl>
*
* secure.cpp: Peer credentials for a UNIX socket.
@@ -67,7 +67,7 @@ SocketSecurity::SocketSecurity(int sockfd)
if (!warned_him) {
kdWarning() << "Using void socket security. Please add support for your" << endl;
- kdWarning() << "platform to kdesu/kdesud/secure.cpp" << endl;
+ kdWarning() << "platform to tdesu/tdesud/secure.cpp" << endl;
warned_him = TRUE;
}
@@ -1,6 +1,6 @@
/* vi: ts=8 sts=4 sw=4
*
- * This file is part of the KDE project, module kdesu.
+ * This file is part of the KDE project, module tdesu.
* Copyright (C) 1999,2000 Geert Jansen <g.t.jansen@stud.tue.nl>
*